@@ -107,7 +107,7 @@ FastHufDecoder::FastHufDecoder
     for (int i = 0; i <= MAX_CODE_LEN; ++i)
     {
         codeCount[i] = 0;
-        base[i]      = 0xffffffffffffffffL;
+        base[i]      = 0xffffffffffffffffULL;
         offset[i]    = 0;
     }
 
@@ -125,12 +125,12 @@ FastHufDecoder::FastHufDecoder
     const int LONG_ZEROCODE_RUN  = 63;
     const int SHORTEST_LONG_RUN  = 2 + LONG_ZEROCODE_RUN - SHORT_ZEROCODE_RUN;
 
-    for (Int64 symbol = minSymbol; symbol <= maxSymbol; symbol++)
+    for (Int64 symbol = static_cast<Int64>(minSymbol); symbol <= static_cast<Int64>(maxSymbol); symbol++)
     {
         if (currByte - table > numBytes)
         {
-            throw Iex::InputExc ("Error decoding Huffman table "
-                                 "(Truncated table data).");
+            throw IEX_NAMESPACE::InputExc ("Error decoding Huffman table "
+                                           "(Truncated table data).");
         }
 
         //
@@ -146,30 +146,30 @@ FastHufDecoder::FastHufDecoder
         {
             if (currByte - table > numBytes)
             {
-                throw Iex::InputExc ("Error decoding Huffman table "
-                                     "(Truncated table data).");
+                throw IEX_NAMESPACE::InputExc ("Error decoding Huffman table "
+                                               "(Truncated table data).");
             }
 
             int runLen = readBits (8, currBits, currBitCount, currByte) +
                          SHORTEST_LONG_RUN;
 
-            if (symbol + runLen > maxSymbol + 1)
+            if (symbol + runLen > static_cast<Int64>(maxSymbol + 1))
             {
-                throw Iex::InputExc ("Error decoding Huffman table "
-                                     "(Run beyond end of table).");
+                throw IEX_NAMESPACE::InputExc ("Error decoding Huffman table "
+                                               "(Run beyond end of table).");
             }
             
             symbol += runLen - 1;
 
         }
-        else if (codeLen >= (Int64) SHORT_ZEROCODE_RUN)
+        else if (codeLen >= static_cast<Int64>(SHORT_ZEROCODE_RUN))
         {
             int runLen = codeLen - SHORT_ZEROCODE_RUN + 2;
 
-            if (symbol + runLen > maxSymbol + 1)
+            if (symbol + runLen > static_cast<Int64>(maxSymbol + 1))
             {
-                throw Iex::InputExc ("Error decoding Huffman table "
-                                     "(Run beyond end of table).");
+                throw IEX_NAMESPACE::InputExc ("Error decoding Huffman table "
+                                               "(Run beyond end of table).");
             }
 
             symbol += runLen - 1;
@@ -255,12 +255,12 @@ FastHufDecoder::FastHufDecoder
         int codeLen = *i & 63;
         int symbol  = *i >> 6;
 
-        if (mapping[codeLen] >= _numSymbols)
+        if (mapping[codeLen] >= static_cast<Int64>(_numSymbols))
         {
             delete[] _idToSymbol;
             _idToSymbol = NULL;
-            throw Iex::InputExc ("Huffman decode error "
-                                  "(Invalid symbol in header).");
+            throw IEX_NAMESPACE::InputExc ("Huffman decode error "
+                                           "(Invalid symbol in header).");
         }
         _idToSymbol[mapping[codeLen]] = symbol;
         mapping[codeLen]++;
@@ -367,7 +367,7 @@ FastHufDecoder::buildTables (Int64 *base, Int64 *offset)
 
     for (int i = 0; i <= MAX_CODE_LEN; ++i)
     {
-        if (base[i] != 0xffffffffffffffffL)
+        if (base[i] != 0xffffffffffffffffULL)
         {
             _ljBase[i] = base[i] << (64 - i);
         }
@@ -377,7 +377,7 @@ FastHufDecoder::buildTables (Int64 *base, Int64 *offset)
             // Unused code length - insert dummy values
             //
 
-            _ljBase[i] = 0xffffffffffffffffL;
+            _ljBase[i] = 0xffffffffffffffffULL;
         }
     }
 
@@ -388,7 +388,8 @@ FastHufDecoder::buildTables (Int64 *base, Int64 *offset)
     // as 'offset', when using the left justified base table.
     //
 
-    for (int i = 0; i <= MAX_CODE_LEN; ++i)
+    _ljOffset[0] = offset[0] - _ljBase[0];
+    for (int i = 1; i <= MAX_CODE_LEN; ++i)
         _ljOffset[i] = offset[i] - (_ljBase[i] >> (64 - i));
 
     //
@@ -410,14 +411,14 @@ FastHufDecoder::buildTables (Int64 *base, Int64 *offset)
                 _tableCodeLen[i] = codeLen;
 
                 Int64 id = _ljOffset[codeLen] + (value >> (64 - codeLen));
-                if (id < _numSymbols)
+                if (id < static_cast<Int64>(_numSymbols))
                 {
                     _tableSymbol[i] = _idToSymbol[id];
                 }
                 else
                 {
-                    throw Iex::InputExc ("Huffman decode error "
-                                          "(Overrun).");
+                    throw IEX_NAMESPACE::InputExc ("Huffman decode error "
+                                                   "(Overrun).");
                 }
                 break;
             }
@@ -432,7 +433,7 @@ FastHufDecoder::buildTables (Int64 *base, Int64 *offset)
 
     int minIdx = TABLE_LOOKUP_BITS;
 
-    while (minIdx > 0 && _ljBase[minIdx] == 0xffffffffffffffffL)
+    while (minIdx > 0 && _ljBase[minIdx] == 0xffffffffffffffffULL)
         minIdx--;
 
     if (minIdx < 0)
@@ -442,7 +443,7 @@ FastHufDecoder::buildTables (Int64 *base, Int64 *offset)
         // Set the min value such that the table is never tested.
         //
 
-        _tableMin = 0xffffffffffffffffL;
+        _tableMin = 0xffffffffffffffffULL;
     }
     else
     {
@@ -593,8 +594,8 @@ FastHufDecoder::decode
      int numDstElems)
 {
     if (numSrcBits < 128)
-        throw Iex::InputExc ("Error choosing Huffman decoder implementation "
-                             "(insufficient number of bits).");
+        throw IEX_NAMESPACE::InputExc ("Error choosing Huffman decoder implementation "
+                                       "(insufficient number of bits).");
 
     //
     // Current position (byte/bit) in the src data stream
@@ -677,19 +678,19 @@ FastHufDecoder::decode
 
             if (codeLen > _maxCodeLength)
             {
-                throw Iex::InputExc ("Huffman decode error "
-                                     "(Decoded an invalid symbol).");
+                throw IEX_NAMESPACE::InputExc ("Huffman decode error "
+                                               "(Decoded an invalid symbol).");
             }
 
             Int64 id = _ljOffset[codeLen] + (buffer >> (64 - codeLen));
-            if (id < _numSymbols)
+            if (id < static_cast<Int64>(_numSymbols))
             {
                 symbol = _idToSymbol[id];
             }
             else
             {
-                throw Iex::InputExc ("Huffman decode error "
-                                     "(Decoded an invalid symbol).");
+                throw IEX_NAMESPACE::InputExc ("Huffman decode error "
+                                               "(Decoded an invalid symbol).");
             }
         }
 
@@ -725,20 +726,20 @@ FastHufDecoder::decode
 
             if (dstIdx < 1)
             {
-                throw Iex::InputExc ("Huffman decode error (RLE code "
-                                     "with no previous symbol).");
+                throw IEX_NAMESPACE::InputExc ("Huffman decode error (RLE code "
+                                               "with no previous symbol).");
             }
 
             if (dstIdx + rleCount > numDstElems)
             {
-                throw Iex::InputExc ("Huffman decode error (Symbol run "
-                                     "beyond expected output buffer length).");
+                throw IEX_NAMESPACE::InputExc ("Huffman decode error (Symbol run "
+                                               "beyond expected output buffer length).");
             }
 
             if (rleCount <= 0) 
             {
-                throw Iex::InputExc("Huffman decode error"
-                                    " (Invalid RLE length)");
+                throw IEX_NAMESPACE::InputExc("Huffman decode error"
+                                              " (Invalid RLE length)");
             }
 
             for (int i = 0; i < rleCount; ++i)
@@ -775,8 +776,8 @@ FastHufDecoder::decode
 
     if (numSrcBits != 0)
     {
-        throw Iex::InputExc ("Huffman decode error (Compressed data remains "
-                             "after filling expected output buffer).");
+        throw IEX_NAMESPACE::InputExc ("Huffman decode error (Compressed data remains "
+                                       "after filling expected output buffer).");
     }
 }
 
