@@ -38,6 +38,7 @@
 //
 //-----------------------------------------------------------------------------
 
+#include "ImfCheckedArithmetic.h"
 #include "ImfInputFile.h"
 #include "ImfScanLineInputFile.h"
 #include "ImfTiledInputFile.h"
@@ -111,6 +112,11 @@ struct InputFile::Data : public Mutex
      Data (int numThreads);
     ~Data ();
 
+    Data (const Data& other) = delete;
+    Data& operator = (const Data& other) = delete;
+    Data (Data&& other) = delete;
+    Data& operator = (Data&& other) = delete;
+
     void		deleteCachedBuffer();
 };
 
@@ -396,7 +402,7 @@ InputFile::InputFile (const char fileName[], int numThreads):
         _data=NULL;
 
         REPLACE_EXC (e, "Cannot read image file "
-			"\"" << fileName << "\". " << e);
+                     "\"" << fileName << "\". " << e.what());
         throw;
     }
     catch (...)
@@ -457,7 +463,7 @@ InputFile::InputFile (OPENEXR_IMF_INTERNAL_NAMESPACE::IStream &is, int numThread
         _data=NULL; 
 
         REPLACE_EXC (e, "Cannot read image file "
-			"\"" << is.fileName() << "\". " << e);
+                     "\"" << is.fileName() << "\". " << e.what());
         throw;
     }
     catch (...)
@@ -537,7 +543,7 @@ InputFile::initialize ()
             _data->compositor->addSource(_data->dsFile);
         }
         
-        else if (isTiled (_data->version))
+        else if (isTiled (_data->version) && !isNonImage(_data->version)) 
         {
             _data->isTiled = true;
             _data->lineOrder = _data->header.lineOrder();
@@ -580,7 +586,7 @@ InputFile::initialize ()
             _data->compositor = new CompositeDeepScanLine;
             _data->compositor->addSource(_data->dsFile);
         }
-        else if (isTiled (_data->header.type()))
+        else if (_data->header.hasType() && _data->header.type()==TILEDIMAGE)
         {
             _data->isTiled = true;
             _data->lineOrder = _data->header.lineOrder();
@@ -687,8 +693,9 @@ InputFile::setFrameBuffer (const FrameBuffer &frameBuffer)
 	    _data->cachedBuffer = new FrameBuffer();
 	    _data->offset = dataWindow.min.x;
 	    
-	    int tileRowSize = (dataWindow.max.x - dataWindow.min.x + 1) *
-			      _data->tFile->tileYSize();
+	    unsigned int tileRowSize =
+                uiMult(dataWindow.max.x - dataWindow.min.x + 1U,
+                       _data->tFile->tileYSize());
 
 	    for (FrameBuffer::ConstIterator k = frameBuffer.begin();
 		 k != frameBuffer.end();
@@ -856,12 +863,45 @@ InputFile::rawPixelData (int firstScanLine,
     catch (IEX_NAMESPACE::BaseExc &e)
     {
 	REPLACE_EXC (e, "Error reading pixel data from image "
-		        "file \"" << fileName() << "\". " << e);
+                 "file \"" << fileName() << "\". " << e.what());
 	throw;
     }
 }
 
 
+
+
+void
+InputFile::rawPixelDataToBuffer (int scanLine,
+                                 char *pixelData,
+                                 int &pixelDataSize) const
+{
+    try
+    {
+        if (_data->dsFile)
+        {
+            throw IEX_NAMESPACE::ArgExc ("Tried to read a raw scanline "
+                                         "from a deep image.");
+        }
+        
+        else if (_data->isTiled)
+        {
+            throw IEX_NAMESPACE::ArgExc ("Tried to read a raw scanline "
+                                         "from a tiled image.");
+        }
+        
+        _data->sFile->rawPixelDataToBuffer(scanLine, pixelData, pixelDataSize);
+    }
+    catch (IEX_NAMESPACE::BaseExc &e)
+    {
+        REPLACE_EXC (e, "Error reading pixel data from image "
+                     "file \"" << fileName() << "\". " << e.what());
+        throw;
+    }
+}
+
+
+
 void
 InputFile::rawTileData (int &dx, int &dy,
 			int &lx, int &ly,
@@ -881,7 +921,7 @@ InputFile::rawTileData (int &dx, int &dy,
     catch (IEX_NAMESPACE::BaseExc &e)
     {
 	REPLACE_EXC (e, "Error reading tile data from image "
-		        "file \"" << fileName() << "\". " << e);
+                 "file \"" << fileName() << "\". " << e.what());
 	throw;
     }
 }
